2. Switched to using a python skeleton
======================================

Date: 2023-03-23

Status
------

Accepted

Context
-------

We should use a python skeleton with the following new development features:
- using a single pyproject.toml instead of requirements.txt and requirements-dev.txt
- black
- isort
- having the git version generated by setup.py instead of versioneer
- mypy
- pre-commit


Decision
--------

We will use the
`DLS python pip skeleton <https://github.com/DiamondLightSource/python3-pip-skeleton>`_.

Consequences
------------

CI workflows will change, even jobs providing the same feature as the older checks.